@@ -241,6 +241,11 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-nix-src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-objc",
+            src_dir: "vendored_parsers/tree-sitter-objc-src",
+            extra_files: vec![],
+        },
         TreeSitterParser {
             name: "tree-sitter-ocaml",
             src_dir: "vendored_parsers/tree-sitter-ocaml-src/ocaml/src",
@@ -336,6 +341,11 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-typescript-src/typescript/src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-vhdl",
+            src_dir: "vendored_parsers/tree-sitter-vhdl-src",
+            extra_files: vec![],
+        },
         TreeSitterParser {
             name: "tree-sitter-xml",
             src_dir: "vendored_parsers/tree-sitter-xml-src/tree-sitter-xml/src",
