@@ -15,9 +15,6 @@
 // Has false positives on else if chains that sometimes have the same
 // body for readability.
 #![allow(clippy::if_same_then_else)]
-// Purely stylistic, and ignores whether there are explanatory
-// comments in the if/else.
-#![allow(clippy::bool_to_int_with_if)]
 // Good practice in general, but a necessary evil for Syntax. Its Hash
 // implementation does not consider the mutable fields, so it is still
 // correct.
@@ -44,8 +41,10 @@ mod words;
 #[macro_use]
 extern crate log;
 
+use display::style::print_warning;
 use log::info;
 use mimalloc::MiMalloc;
+use options::USAGE;
 
 use crate::conflicts::apply_conflict_markers;
 use crate::conflicts::START_LHS_MARKER;
@@ -71,9 +70,9 @@ use crate::parse::syntax;
 #[global_allocator]
 static GLOBAL: MiMalloc = MiMalloc;
 
-use std::sync::atomic::{AtomicBool, Ordering};
-use std::sync::Arc;
-use std::{env, path::Path};
+use std::fs::Permissions;
+use std::path::Path;
+use std::{env, thread};
 
 use humansize::{format_size, BINARY};
 use owo_colors::OwoColorize;
@@ -221,7 +220,7 @@ fn main() {
             lhs_path,
             rhs_path,
             display_path,
-            old_path,
+            renamed,
         } => {
             if lhs_path == rhs_path {
                 let is_dir = match &lhs_path {
@@ -229,20 +228,21 @@ fn main() {
                     _ => false,
                 };
 
-                eprintln!(
-                    "warning: You've specified the same {} twice.\n",
-                    if is_dir { "directory" } else { "file" }
+                print_warning(
+                    &format!(
+                        "You've specified the same {} twice.",
+                        if is_dir { "directory" } else { "file" }
+                    ),
+                    &display_options,
                 );
             }
 
-            let encountered_changes = Arc::new(AtomicBool::new(false));
+            let mut encountered_changes = false;
             match (&lhs_path, &rhs_path) {
                 (
                     options::FileArgument::NamedPath(lhs_path),
                     options::FileArgument::NamedPath(rhs_path),
                 ) if lhs_path.is_dir() && rhs_path.is_dir() => {
-                    let encountered_changes = encountered_changes.clone();
-
                     // Diffs in parallel when iterating this iterator.
                     let diff_iter = diff_directories(
                         lhs_path,
@@ -253,62 +253,49 @@ fn main() {
                     );
 
                     if matches!(display_options.display_mode, DisplayMode::Json) {
-                        let results = diff_iter
-                            .map(|diff_result| {
-                                if diff_result.has_reportable_change() {
-                                    encountered_changes.store(true, Ordering::Relaxed);
-                                }
-
-                                diff_result
-                            })
-                            .collect();
-
+                        let results: Vec<_> = diff_iter.collect();
+                        encountered_changes = results
+                            .iter()
+                            .any(|diff_result| diff_result.has_reportable_change());
                         display::json::print_directory(results);
+                    } else if display_options.sort_paths {
+                        let mut result: Vec<DiffResult> = diff_iter.collect();
+                        result.sort_unstable_by(|a, b| a.display_path.cmp(&b.display_path));
+                        for diff_result in result {
+                            print_diff_result(&display_options, &diff_result);
+
+                            if diff_result.has_reportable_change() {
+                                encountered_changes = true;
+                            }
+                        }
                     } else {
-                        if display_options.sort_paths {
-                            let mut result: Vec<DiffResult> = diff_iter.collect();
-                            result.sort_unstable_by(|a, b| a.display_path.cmp(&b.display_path));
-                            for diff_result in result {
+                        // We want to diff files in the directory in
+                        // parallel, but print the results serially
+                        // (to prevent display interleaving).
+                        // https://github.com/rayon-rs/rayon/issues/210#issuecomment-551319338
+                        thread::scope(|s| {
+                            let (send, recv) = std::sync::mpsc::sync_channel(1);
+
+                            s.spawn(move || {
+                                diff_iter
+                                    .try_for_each_with(send, |s, diff_result| s.send(diff_result))
+                                    .expect("Receiver should be connected")
+                            });
+
+                            for diff_result in recv.into_iter() {
                                 print_diff_result(&display_options, &diff_result);
 
                                 if diff_result.has_reportable_change() {
-                                    encountered_changes.store(true, Ordering::Relaxed);
+                                    encountered_changes = true;
                                 }
                             }
-                        } else {
-                            // We want to diff files in the directory in
-                            // parallel, but print the results serially (to
-                            // prevent display interleaving).
-                            // https://github.com/rayon-rs/rayon/issues/210#issuecomment-551319338
-                            let (send, recv) = std::sync::mpsc::sync_channel(1);
-
-                            let encountered_changes = encountered_changes.clone();
-                            let print_options = display_options.clone();
-
-                            let printing_thread = std::thread::spawn(move || {
-                                for diff_result in recv.into_iter() {
-                                    print_diff_result(&print_options, &diff_result);
-
-                                    if diff_result.has_reportable_change() {
-                                        encountered_changes.store(true, Ordering::Relaxed);
-                                    }
-                                }
-                            });
-
-                            diff_iter
-                                .try_for_each_with(send, |s, diff_result| s.send(diff_result))
-                                .expect("Receiver should be connected");
-
-                            printing_thread
-                                .join()
-                                .expect("Printing thread should not panic");
-                        }
+                        });
                     }
                 }
                 _ => {
                     let diff_result = diff_file(
                         &display_path,
-                        old_path,
+                        renamed,
                         &lhs_path,
                         &rhs_path,
                         &display_options,
@@ -317,7 +304,7 @@ fn main() {
                         &language_overrides,
                     );
                     if diff_result.has_reportable_change() {
-                        encountered_changes.store(true, Ordering::Relaxed);
+                        encountered_changes = true;
                     }
 
                     match display_options.display_mode {
@@ -331,7 +318,7 @@ fn main() {
                 }
             }
 
-            let exit_code = if set_exit_code && encountered_changes.load(Ordering::Relaxed) {
+            let exit_code = if set_exit_code && encountered_changes {
                 EXIT_FOUND_CHANGES
             } else {
                 EXIT_SUCCESS
@@ -341,10 +328,66 @@ fn main() {
     };
 }
 
+#[cfg(unix)]
+fn compare_permissions(lhs: &Permissions, rhs: &Permissions) -> Option<String> {
+    use std::os::unix::fs::PermissionsExt;
+
+    let lhs_mode = lhs.mode();
+    let rhs_mode = rhs.mode();
+
+    if lhs_mode != rhs_mode {
+        let lhs_mode = format!("{:o}", lhs_mode);
+        let rhs_mode = format!("{:o}", rhs_mode);
+        Some(format!(
+            "File permissions changed from {} to {}.",
+            lhs_mode, rhs_mode
+        ))
+    } else {
+        None
+    }
+}
+
+#[cfg(windows)]
+fn compare_permissions(lhs: &Permissions, rhs: &Permissions) -> Option<String> {
+    if lhs.readonly() != rhs.readonly() {
+        Some(format!(
+            "File permissions changed from {} to {}.",
+            if lhs.readonly() {
+                "readonly"
+            } else {
+                "read-write"
+            },
+            if rhs.readonly() {
+                "readonly"
+            } else {
+                "read-write"
+            },
+        ))
+    } else {
+        None
+    }
+}
+
+#[cfg(not(any(unix, windows)))]
+fn compare_permissions(_lhs: &Permissions, _rhs: &Permissions) -> Option<String> {
+    None
+}
+
+fn describe_permissions_change(lhs_path: &FileArgument, rhs_path: &FileArgument) -> Option<String> {
+    match (lhs_path, rhs_path) {
+        (FileArgument::NamedPath(lhs_path), FileArgument::NamedPath(rhs_path)) => {
+            let lhs_metadata = std::fs::metadata(lhs_path).ok()?;
+            let rhs_metadata = std::fs::metadata(rhs_path).ok()?;
+            compare_permissions(&lhs_metadata.permissions(), &rhs_metadata.permissions())
+        }
+        _ => None,
+    }
+}
+
 /// Print a diff between two files.
 fn diff_file(
     display_path: &str,
-    extra_info: Option<String>,
+    renamed: Option<String>,
     lhs_path: &FileArgument,
     rhs_path: &FileArgument,
     display_options: &DisplayOptions,
@@ -356,7 +399,7 @@ fn diff_file(
     let (mut lhs_src, mut rhs_src) = match (guess_content(&lhs_bytes), guess_content(&rhs_bytes)) {
         (ProbableFileKind::Binary, _) | (_, ProbableFileKind::Binary) => {
             return DiffResult {
-                extra_info,
+                extra_info: renamed,
                 display_path: display_path.to_owned(),
                 file_format: FileFormat::Binary,
                 lhs_src: FileContent::Binary,
@@ -376,6 +419,16 @@ fn diff_file(
         rhs_src.retain(|c| c != '\r');
     }
 
+    let mut extra_info = renamed;
+    if let Some(permissions_change) = describe_permissions_change(lhs_path, rhs_path) {
+        if let Some(extra_info) = &mut extra_info {
+            extra_info.push('\n');
+            extra_info.push_str(&permissions_change);
+        } else {
+            extra_info = Some(permissions_change);
+        }
+    }
+
     diff_file_content(
         display_path,
         extra_info,
@@ -419,9 +472,13 @@ fn diff_conflicts_file(
 
     if conflict_files.num_conflicts == 0 {
         eprintln!(
-            "warning: Expected a file with conflict markers {}, but none were found. See --help for usage instructions.\n",
+            "error: Difftastic requires two paths, or a single file with conflict markers {}.\n",
             START_LHS_MARKER,
         );
+
+        eprintln!("USAGE:\n\n    {}\n", USAGE);
+        eprintln!("For more information try --help");
+        std::process::exit(EXIT_BAD_ARGUMENTS);
     }
 
     let lhs_name = match conflict_files.lhs_name {
@@ -500,7 +557,7 @@ fn diff_file_content(
             None => FileFormat::PlainText,
         };
 
-        // If the two files are completely identical, return early
+        // If the two files are byte-for-byte identical, return early
         // rather than doing any more work.
         return DiffResult {
             extra_info,
