@@ -53,6 +53,7 @@ pub(crate) enum Language {
     Make,
     Newick,
     Nix,
+    ObjC,
     OCaml,
     OCamlInterface,
     Pascal,
@@ -72,6 +73,7 @@ pub(crate) enum Language {
     Toml,
     TypeScript,
     TypeScriptTsx,
+    Vhdl,
     Xml,
     Yaml,
     Zig,
@@ -140,6 +142,7 @@ pub(crate) fn language_name(language: Language) -> &'static str {
         Make => "Make",
         Newick => "Newick",
         Nix => "Nix",
+        ObjC => "Objective-C",
         OCaml => "OCaml",
         OCamlInterface => "OCaml Interface",
         Pascal => "Pascal",
@@ -159,6 +162,7 @@ pub(crate) fn language_name(language: Language) -> &'static str {
         Toml => "TOML",
         TypeScript => "TypeScript",
         TypeScriptTsx => "TypeScript TSX",
+        Vhdl => "VHDL",
         Xml => "XML",
         Yaml => "YAML",
         Zig => "Zig",
@@ -317,6 +321,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
         ],
         Newick => &["*.nhx", "*.nwk", "*.nh"],
         Nix => &["*.nix"],
+        ObjC => &["*.m"],
         OCaml => &["*.ml"],
         OCamlInterface => &["*.mli"],
         Pascal => &["*.pas", "*.dfm", "*.dpr", "*.lpr", "*.pascal"],
@@ -349,6 +354,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
         ],
         TypeScript => &["*.ts"],
         TypeScriptTsx => &["*.tsx"],
+        Vhdl => &["*.vhdl", "*.vhd"],
         Xml => &[
             "*.ant",
             "*.csproj",
@@ -362,6 +368,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "*.xsd",
             "*.xsl",
             "*.xslt",
+            "*.zcml",
             "App.config",
             "nuget.config",
             "packages.config",
@@ -391,6 +398,28 @@ fn looks_like_hacklang(path: &Path, src: &str) -> bool {
     false
 }
 
+/// Use a heuristic to determine if a '.h' file looks like Objective-C.
+/// We look for a line starting with '#import', '@interface' or '@protocol'
+/// near the top of the file.  These keywords are not valid C or C++, so this
+/// should not produce false positives.
+fn looks_like_objc(path: &Path, src: &str) -> bool {
+    if let Some(extension) = path.extension() {
+        if extension == "h" {
+            return src.lines().take(100).any(|line| {
+                ["#import", "@interface", "@protocol"]
+                    .iter()
+                    .any(|keyword| line.starts_with(keyword))
+            });
+        }
+    }
+
+    false
+}
+
+fn looks_like_xml(src: &str) -> bool {
+    src.starts_with("<?xml")
+}
+
 pub(crate) fn guess(
     path: &Path,
     src: &str,
@@ -418,13 +447,25 @@ pub(crate) fn guess(
     if let Some(lang) = from_shebang(src) {
         return Some(lang);
     }
+
+    // Handle cases where file detection should override globbing,
+    // specifically *.php as potentially Hack or *.h as potentially
+    // Objective-C.
     if looks_like_hacklang(path, src) {
         return Some(Language::Hack);
     }
+    if looks_like_objc(path, src) {
+        return Some(Language::ObjC);
+    }
+
     if let Some(lang) = from_glob(path) {
         return Some(lang);
     }
 
+    if looks_like_xml(src) {
+        return Some(Language::Xml);
+    }
+
     None
 }
 
@@ -468,6 +509,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             "js" | "js2" => Some(JavaScript),
             "lisp" => Some(CommonLisp),
             "nxml" => Some(Xml),
+            "objc" => Some(ObjC),
             "perl" => Some(Perl),
             "python" => Some(Python),
             "racket" => Some(Racket),
@@ -483,6 +525,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             "toml" => Some(Toml),
             "tuareg" => Some(OCaml),
             "typescript" => Some(TypeScript),
+            "vhdl" => Some(Vhdl),
             "yaml" => Some(Yaml),
             "zig" => Some(Zig),
             _ => None,
@@ -616,6 +659,15 @@ mod tests {
         assert_eq!(guess(path, "# -*-python-*-", &[]), Some(Python));
     }
 
+    #[test]
+    fn test_guess_by_xml_header() {
+        let path = Path::new("foo");
+        assert_eq!(
+            guess(path, "<?xml version=\"1.0\" encoding=\"utf-8\"?>", &[]),
+            Some(Xml)
+        );
+    }
+
     #[test]
     fn test_guess_unknown() {
         let path = Path::new("jfkdlsjfkdsljfkdsljf");
