@@ -94,6 +94,7 @@ extern "C" {
     fn tree_sitter_make() -> ts::Language;
     fn tree_sitter_newick() -> ts::Language;
     fn tree_sitter_nix() -> ts::Language;
+    fn tree_sitter_objc() -> ts::Language;
     fn tree_sitter_ocaml() -> ts::Language;
     fn tree_sitter_ocaml_interface() -> ts::Language;
     fn tree_sitter_pascal() -> ts::Language;
@@ -113,6 +114,7 @@ extern "C" {
     fn tree_sitter_toml() -> ts::Language;
     fn tree_sitter_tsx() -> ts::Language;
     fn tree_sitter_typescript() -> ts::Language;
+    fn tree_sitter_vhdl() -> ts::Language;
     fn tree_sitter_xml() -> ts::Language;
     fn tree_sitter_yaml() -> ts::Language;
     fn tree_sitter_zig() -> ts::Language;
@@ -739,6 +741,27 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        ObjC => {
+            let language = unsafe { tree_sitter_objc() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string_literal"].into_iter().collect(),
+                delimiter_tokens: vec![
+                    ("(", ")"),
+                    ("{", "}"),
+                    ("[", "]"),
+                    ("@(", ")"),
+                    ("@{", "}"),
+                    ("@[", "]"),
+                ],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/objc.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         OCaml => {
             let language = unsafe { tree_sitter_ocaml() };
             TreeSitterConfig {
@@ -1085,6 +1108,20 @@ pub(crate) fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        Vhdl => {
+            let language = unsafe { tree_sitter_vhdl() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec![].into_iter().collect(),
+                delimiter_tokens: vec![("(", ")")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/vhdl.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Zig => {
             let language = unsafe { tree_sitter_zig() };
             TreeSitterConfig {
